PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/reader.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

reader.h
Go to the documentation of this file.
1
9 #ifndef READER_H
10 #define READER_H
11 #include "utils.h"
12
13 typedef struct WAVECAR_FILE {
14 int type;
15 FILE* fp;
16 char* start;
17 char* curr;
18 } WAVECAR;
19
20 WAVECAR* wcopen(char* f, int type);
21
22 void wcseek(WAVECAR* wc, long loc);
23
24 void wcread(void* ptr0, long size, long nmemb, WAVECAR* wc);
25
26 void wcclose(WAVECAR* wc);
27
31 void setup(int nrecl, int nprec, int nspin, int nwk, int nband,
32 double* nb1, double* nb2, double* nb3, double ecut,
33 double* lattice, double* reclattice);
34
39 pswf_t* read_wavecar(WAVECAR* wc, double* kpt_weights);
40
46 pswf_t* read_wavefunctions(char* filename, double* kpt_weights);
47
52 pswf_t* read_wavefunctions_from_str(char* start, double* kpt_weights);
53
57 kpoint_t** read_one_band(int* G_bounds, double* kpt_weights, int* ns, int* nk, int* nb, int BAND_NUM, char* filename);
58
59 #endif
60
WAVECAR
struct WAVECAR_FILE WAVECAR
read_wavefunctions_from_str
pswf_t * read_wavefunctions_from_str(char *start, double *kpt_weights)
wcopen
WAVECAR * wcopen(char *f, int type)
WAVECAR_FILE::fp
FILE * fp
Definition: reader.h:15
wcclose
void wcclose(WAVECAR *wc)
WAVECAR_FILE::curr
char * curr
Definition: reader.h:17
wcseek
void wcseek(WAVECAR *wc, long loc)
kpoint
Definition: utils.h:101
read_wavecar
pswf_t * read_wavecar(WAVECAR *wc, double *kpt_weights)
pawpyseed.core.gaunt.f
f
Definition: gaunt.py:28
utils.h
setup
void setup(int nrecl, int nprec, int nspin, int nwk, int nband, double *nb1, double *nb2, double *nb3, double ecut, double *lattice, double *reclattice)
wcread
void wcread(void *ptr0, long size, long nmemb, WAVECAR *wc)
read_one_band
kpoint_t ** read_one_band(int *G_bounds, double *kpt_weights, int *ns, int *nk, int *nb, int BAND_NUM, char *filename)
WAVECAR_FILE::start
char * start
Definition: reader.h:16
pswf
Definition: utils.h:112
WAVECAR_FILE::type
int type
Definition: reader.h:14
WAVECAR_FILE
Definition: reader.h:13
read_wavefunctions
pswf_t * read_wavefunctions(char *filename, double *kpt_weights)